@@ -34,7 +34,9 @@ class NewAnalytics(base.NewAPIClient):
             _data["group_by"] = group_by
 
         request = requests.get(
-            f"{self.api_base}/analytics/date", headers=self.headers_default, params=_data
+            f"{self.api_base}/analytics/date",
+            headers=self.headers_default,
+            params=_data,
         )
 
         return request.text
